%% This is file `baltzer.cls'
%%
%% This class file loads standart "article.cls" with appropriate 
%% settings and then style file "imsart.sty" with additional macros
%%
%% You are free to use this style file as you see fit, provided 
%% that you do not make changes to the file. 
%% If you DO make changes, you are required to rename this file.
%%
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.0 or, at your option, any later version.
%%
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
%%
%% Bug fixes and changes: at end of file

% TeX programming: Linas Stonys, VTeX, Lithuania, lstonys@vtex.lt
% Requires Latex2e, ver.2000.06


\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{baltzer}[2011/08/02 driver class for package imsart.sty]

\def\mainclass{article}
\PassOptionsToClass{11pt,a4paper}{\mainclass}
\PassOptionsToPackage{psamsfonts}{amssymb}
\PassOptionsToPackage{cmex10}{amsmath}

\newif\if@@twoside \@@twosidefalse
\DeclareOption{oneside}{\global\@@twosidefalse}
\DeclareOption{twoside}{\global\@@twosidetrue}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{\mainclass}}
\ProcessOptions*
\LoadClass{\mainclass}

\IfFileExists{imsart.sty}{}{\ClassError{imsart}{The complimentary style file "imsart.sty" is required}{
The complimentary style file "imsart.sty" is required\MessageBreak
You need to install file "imsart.sty" in your system\MessageBreak
File could be downloaded from http://www.e-publications.org/ims/support
}}
% Load additional macros and modifications for "article.cls"
\RequirePackage[generic]{imsart}


%\textwidth=32pc
%\textheight=196mm
% Page size
% \set@page@layout{\textwidth}{\textheight}
\def\set@page@layout#1#2{%
%
  \setlength\textwidth{#1}
  \@settopoint\textwidth
  \setlength\textheight{#2}
  \@settopoint\textheight
%
  \if@@twoside
    \setlength\@tempdima        {\paperwidth}
    \addtolength\@tempdima      {-\textwidth}
    \setlength\oddsidemargin    {.4\@tempdima}
    \addtolength\oddsidemargin  {-1in}
    \setlength\marginparwidth   {.6\@tempdima}
    \addtolength\marginparwidth {-\marginparsep}
    \addtolength\marginparwidth {-0.4in}
  \else
	% make side margins equal:
    \setlength\@tempdima        {\paperwidth}
    \addtolength\@tempdima      {-\textwidth}
    \setlength\oddsidemargin    {.5\@tempdima}
    \addtolength\oddsidemargin  {-1in}
    \setlength\marginparwidth   {.5\@tempdima}
    \addtolength\marginparwidth {-\marginparsep}
    \addtolength\marginparwidth {-0.4in}
    \addtolength\marginparwidth {-.4in}
  \fi
  \ifdim \marginparwidth >2in
     \setlength\marginparwidth{2in}
  \fi
  \@settopoint\oddsidemargin
  \@settopoint\marginparwidth
  \setlength\evensidemargin  {\paperwidth}
  \addtolength\evensidemargin{-2in}
  \addtolength\evensidemargin{-\textwidth}
  \addtolength\evensidemargin{-\oddsidemargin}
  \@settopoint\evensidemargin
%
% topmargin
  \setlength\topmargin{\paperheight}
  \addtolength\topmargin{-2in}
  \addtolength\topmargin{-\headheight}
  \addtolength\topmargin{-\headsep}
  \addtolength\topmargin{-\textheight}
  \addtolength\topmargin{-\footskip}     % this might be wrong!
  \addtolength\topmargin{-.5\topmargin}
  \@settopoint\topmargin
}

\set@page@layout{32pc}{196mm}% 32pc=~135mm 
\headsep 1.3\baselineskip
\footskip18pt
\topskip = 10pt
\parskip 0pt
\parindent 2pc
\footnotesep 6.65pt
%
\fboxsep = 7pt
\fboxrule = 0.4pt
%%
\RequirePackage{times}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% pubyear, volume, paperno
\def\@copyrightyear{(2011) }
\def\@pubyear{}
\def\pubyear#1{\gdef\@pubyear{(#1) }\gdef\@copyrightyear{(#1) }}

\def\volumetitle#1{\gdef\volume@title{#1 }}

\gdef\@volume{0}
\def\volume#1{\gdef\@volume{#1}}
\def\journal@name{}
\gdef\journal#1{\gdef\journal@name{#1}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Frontmatter settings
\def\theaddressref{\alph{addressref}}
\def\abstractname{}
\setattribute{abstractname}{skip} {\indent}
\setattribute{keyword}{KWD}{Keywords:}
\setattribute{copyright}  {text} {{\journal@name} \@volume\ \@ifnonempty{\@copyrightyear\@pagerange}\hfill\thepage\break\doi@text}
\setattribute{copyright}  {foottext} {\textcopyright\ Baltzer Science Publishers}

\newcommand\titlesize{\@setfontsize\titlesize{16}{20.5}}
\setattribute{title}      {size} {\titlesize}
\setattribute{author}     {size} {\normalsize}

\setattribute{authors}     {skip} {16pt}
\setattribute{title}       {skip} {32\p@}
\setattribute{abstract}    {skip} {10mm}
\setattribute{keyword}     {skip} {7\p@}
\setattribute{frontmatter} {cmd}  {\vskip18\p@ plus 3\p@ minus 3\p@
                                   \@afterindentfalse\@afterheading}
\setattribute{twocolumnfrontmatter} {skip}  {\vskip18\p@ plus 3\p@ minus 3\p@}
\setattribute{ead}       {size} {\upshape}
\setattribute{doi}       {text} {\url@fmt {url: }{}{\paper@url }{\paper@url }}

\def\doi#1{%
  \gdef\@doi{#1}%
  \gdef\doi@text{\url@fmt{DOI: }{}{#1}{\doi@base\@doi}}%
}

                                   
\def\close@fm{%
  \if@twocolumn
	\csname twocolumnfrontmatter@skip\endcsname
  \fi
  \par \egroup
  \fm@size=\dp\fm@box \advance\fm@size by \ht\fm@box
  \@whiledim\fm@size>\t@xtheight \do{%
    \global\setbox\@tempboxa=\vsplit\fm@box to \t@xtheight
    \unvbox\@tempboxa 
    \fm@size=\dp\fm@box \advance\fm@size by \ht\fm@box}
  \if@twocolumn
  	\emergencystretch=1pc\twocolumn[\unvbox\fm@box]
  \else
    \unvbox\fm@box
  \fi}

\newdimen\abs@width \abs@width\textwidth
\advance\abs@width-2\parindent
\setattribute{abstract}   {width}  {\abs@width}
\setattribute{keyword}    {width}  {\abs@width}

\def\email@text{\normalfont\selectfont E-mail: }
\def\url@text{\normalfont\selectfont url: }
\def\fullurl@text{\normalfont\selectfont url: }

\def\affiliation{\@ifnextchar[{\affiliation@fmt}{\affiliation@fmt[]}}

%*************************** SECTIONS

\newskip\Bls@  \Bls@=22pt plus 2pt minus 2pt% approx. 2 baselineskip
\newskip\bls@  \bls@=11pt plus 1pt minus 3pt% approx. 1 baselineskip
\newskip\eps@  \eps@=0.0001pt                      % small positive skip

\renewcommand\section{\@startsection{section}{1}{\z@}%
	{\Bls@}%
	{\bls@}%
	{\normalsize\bfseries\nohyphen\raggedright}}

\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
	{12pt plus 3pt}%
	{\bls@}%
	{\normalsize\itshape\nohyphen\raggedright}}

\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
	{\baselineskip}%
	{\eps@}%
	{\normalsize\itshape\nohyphen\raggedright}}

\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
	{\bls@}%
	{-1em}%
	{\normalfont\normalsize\itshape}}

\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
  	{\eps@}
  	{-1em}
  	{\normalfont\normalsize\itshape}}
%
\setcounter{secnumdepth}{3}


\def\@seccntformat#1{{\csname #1@prefix\endcsname\csname the#1\endcsname\csname#1@numbersep\endcsname\hskip1em}}

\renewcommand\appendix{\par
   \def\section@prefix{\appendixname\ }%
   \setcounter{section}{0}%
   \setcounter{subsection}{0}%
   \def\thesection{\Alph{section}}}

% **************************** THEOREMS
\def\set@amsthm@{%
    \newtheoremstyle{plain}     {\medskipamount}{\medskipamount}{\normalfont}{\z@}{\bfseries}{.}{1em}{}
}
\AtBeginDocument{\@ifpackageloaded{amsthm}{\set@amsthm@}{}}


% **************************** FOOTNOTE *
%
\def\footnoterule{\hfill}%
\newdimen\foot@leftskip 
\def\setfootskip#1{\setbox\@tempboxa\hbox{#1}%
	\global\foot@leftskip=\wd\@tempboxa}
\setfootskip{$^{\mathrm{1}}\,$}
\long\def\@makefntext#1{\footnotesize
	\leftskip\foot@leftskip\leavevmode\noindent\hbox{}\llap{$^{\mathrm{\@thefnmark}}\,$}%
	\parindent1em #1}
\def\freefootnotetext[#1]{%
    \begingroup\unrestored@protected@xdef\@thefnmark{#1}\endgroup\@footnotetext}

% ****************  LISTS 
\newdimen\labelwidthi
\newdimen\labelwidthii
\newdimen\labelwidthiii
\newdimen\labelwidthiv
%
\newdimen\widthenumi
\newdimen\widthenumii
\newdimen\widthenumiii
\newdimen\widthenumiv

\newcommand\normal@labelsep{0.5em}
\labelsep\normal@labelsep
%
\settowidth{\labelwidthi}{(iii)}
\settowidth{\labelwidthii}{(d)}
\settowidth{\labelwidthiii}{(iii)}
\settowidth{\labelwidthiv}{(M)}
%
\settowidth{\widthenumi}{10.}
\settowidth{\widthenumii}{(d)}
\settowidth{\widthenumiii}{iii.}
\settowidth{\widthenumiv}{M.}
%
\leftmargini\labelwidthi    \advance\leftmargini\labelsep
\leftmarginii\labelwidthii  \advance\leftmarginii\labelsep
\leftmarginii\labelwidthiii \advance\leftmarginiii\labelsep
\leftmarginii\labelwidthiv  \advance\leftmarginiv\labelsep
%

\renewcommand\labelitemi{$\m@th\bullet$}
\renewcommand\labelitemii{$\m@th\ast$} 
\renewcommand\labelitemiii{$\m@th\ast$}               %\ast
\renewcommand\labelitemiv{{\footnotesize +}}               %\footnotesize +
%

% QUOTATION
\let\quotation@size\normalsize
\def\quotation@itemindent{\z@}
\def\quotation@leftmargin{1pc}
\let\quotation@rightmargin\z@

% QUOTE
\let\quote@size\normalsize
\def\quote@leftmargin{1pc}
\def\quote@rightmargin{\z@}

%
% DESCRIPTION 
%
% To change the formatting of the label, you must redefine 
% \descriptionlabel. 
\def\descriptionlabel#1{\hspace\labelsep \bfseries #1}
\renewenvironment{description}
 {\list{}{\labelwidth\z@ 
  \leftmargin 1pc \itemindent-\leftmargin
  \let\makelabel\descriptionlabel}}
 {\endlist}
%

% figures, tables
\setattribute{tablename}   {size} {}
\setattribute{tablecaption}{size} {\footnotesize}

\setattribute{figurecaption}{size}{\footnotesize}
\setattribute{figurename}   {size}{}
\def\figurename{Figure}


% headings
\def\ps@copyright{\let\@mkboth\@gobbletwo%
  \def\@evenhead{\parbox[t]{\textwidth}{\copyright@size\copyright@text}}%
  \let\@oddhead\@evenhead%
  \def\@oddfoot{\copyright@size\copyright@foottext\hfill}%
  \let\@evenfoot\@oddfoot}

\def\headingssplit{\ /\ }
\def\ps@headings{\let\@mkboth\@gobbletwo
  \def\@oddfoot{}\def\@evenfoot{}%        % No running footers.
  \def\@evenhead{\footnotesize\rlap{\thepage}\hfil{\em \leftmark}\hfil%V.S.
     \hbox{}}%                            % Left running header.
  \def\@oddhead{\footnotesize\hfil{\em\rightmark}%V.S.
    \hfil \llap{\thepage}}%               % Right running header.
    \def\leftmark{\@runauthor\headingssplit\@runtitle} \let\rightmark\leftmark}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% AUTHOR
%

\newif\ifauthor@corref

\define@key{author}{addressref}{%
	\@ifundefined{authors@fnmark@list}{\xdef\authors@fnmark@list{#1}}{\xdef\authors@fnmark@list{\authors@fnmark@list,#1}}%
}

\define@key{author}{corref}[true]{%
 	\@ifundefined{authors@fnmark@list}{\xdef\authors@fnmark@list{#1}}{\xdef\authors@fnmark@list{\authors@fnmark@list,correfmark}}%
 	\author@correftrue%
}

\define@key{author}{thanksref}[true]{%
	\@ifundefined{authors@fnmark@list}{\xdef\authors@fnmark@list{#1}}{\xdef\authors@fnmark@list{\authors@fnmark@list,#1}}%
}

\def\author{\@ifnextchar[{\author@fmt}{\author@fmt[]}}
\let\a@sep\relax

\newtoks\@toksa
\def\author@fmt[#1]#2{%
  \stepcounter{author}{%
  \csname author@cmd\endcsname%
  \author@correffalse%
  \xdef\author@id{au\the\c@author}%
  \setkeys{author}{#1}%
  \let\a@sep\author@sep%
  \ifnum\c@author=1 \author@fmt@init \let\a@sep\relax\fi%
  \bgroup%
    \def\inits##1{##1}\def\fnm##1{}\def\particle##1{##1}\def\snm##1{##1}\def\suffix##1{##1}%
    \def\degs##1{##1}%
    \def\collab##1{##1}%
    \def\postfix##1{##1}%
    \def\affprefix##1{##1}%
    \def\authblock##1{}%
    \def\addrblock##1{##1}%
    \no@harm%
    \xdef\author@arg{#2}%
  \egroup%
  \expandafter\protected@xdef\csname author@\author@id\endcsname{\author@arg}%
  \bgroup%
    \def\inits##1{}\def\fnm##1{##1}\def\particle##1{##1}\def\snm##1{##1}\def\suffix##1{##1}%
    \def\degs##1{##1}%
    \def\collab##1{##1}%
    \def\postfix##1{##1}%
    \def\affprefix##1{##1}%
    \def\authblock##1{}%
    \def\addrblock##1{##1}%
    \no@harm%
    \xdef\author@arg{#2}%
  \egroup%
  \expandafter\protected@xdef\csname fauthor@\author@id\endcsname{\author@arg}%
  \bgroup% 
     \author@size%
     \def\inits##1{}\def\fnm##1{##1}\def\particle##1{##1}\def\snm##1{##1}\def\suffix##1{##1}%
     \def\degs##1{##1}%
     \def\collab##1{##1}%
     \def\postfix##1{\@toksa={##1}}%
     \def\prefix##1{##1}% 
     \def\authblock##1{##1}%
     \def\addrblock##1{}%
     \ifnum\c@author=1\addto@authors@list{#2}\else\addto@authors@list{, #2}\fi%
     %\a@sep
     \authorname@fmt{#2}%
	 \@ifundefined{authors@fnmark@list}{}{\thanksref{\authors@fnmark@list}}%
     \author@hook%
  \egroup}%
  \ignorespaces}


\def\author@fmt@init{%
   \vskip\authors@skip%
   \leavevmode}

%Corresponding author
%\let\author@hook\relax
\def\@corrthankstext[#1]#2#3{%
  \@thankslabel[#1]{#2}%
  \protected@xdef\@thanks{\protect\thanks@thefnmark{#2thanks}%
  \protect\orig@footnotetext{\thanks@hypertarget{#2}#3}\@thanks}}%

\def\corref@text@printed{0}
\def\author@hook{%
	\global\let\authors@fnmark@list\undefined
  	\ifauthor@corref%
  		\ifnum0=\corref@text@printed
  			\let\@save@thankstext\@thankstext
  			\let\@thankstext\@corrthankstext
  			\thankstext[*]{correfmark}{Corresponding author.}\gdef\corref@text@printed{1}%
			\let\@thankstext\@save@thankstext
  		\fi
	\fi
}
\def\authorname@fmt#1{#1}
%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\@fnsymbol#1{\ensuremath{\ifcase#1\or \star\or \dagger\or \ddagger\or
   \mathsection\or \mathparagraph\or \|\or **\or \dagger\dagger
   \or \ddagger\ddagger \else\@ctrerr\fi}}

\def\hy@endfrontmatter{\if@twocolumn\@thanks\fi}
\ps@headings   

\AtBeginDocument{\def\bibfont{\footnotesize}}

\endinput
